@@ -103,6 +103,18 @@ Tcl_AppInit(interp)
      * then no user-specific startup file will be run under any conditions.
      */
 
-    tcl_RcFileName = "~/.cwishrc";
+    Tcl_SetVar(interp, "tcl_rcFileName", "~/.cwishrc", TCL_GLOBAL_ONLY);
     return TCL_OK;
 }
+
+#if TCL_MAJOR_VERSION >= 8
+#if 0
+void panic(const char *msg)
+{
+  fprintf(stderr, msg);
+  exit(1);
+}
+#endif
+#else
+  #error TCL_MAJOR_VERSION
+#endif
