@@ -408,7 +408,7 @@ ButtonCreate(clientData, interp, argc, argv, type)
 	return TCL_ERROR;
     }
 
-    interp->result = Tk_PathName(butPtr->tkwin);
+    Tcl_SetResult(interp, Tk_PathName(butPtr->tkwin), TCL_VOLATILE);
     return TCL_OK;
 }
 
@@ -441,11 +441,13 @@ ButtonWidgetCmd(clientData, interp, argc, argv)
     int result = TCL_OK;
     size_t length;
     int c;
+    char error_buffer[120];
 
     if (argc < 2) {
-	sprintf(interp->result,
+	sprintf(error_buffer,
 		"wrong # args: should be \"%.50s option ?arg arg ...?\"",
 		argv[0]);
+	Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
 	return TCL_ERROR;
     }
     Tk_Preserve((ClientData) butPtr);
@@ -477,9 +479,10 @@ ButtonWidgetCmd(clientData, interp, argc, argv)
     } else if ((c == 'd') && (strncmp(argv[1], "deselect", length) == 0)
 	    && (butPtr->type >= TYPE_CHECK_BUTTON)) {
 	if (argc > 2) {
-	    sprintf(interp->result,
+	    sprintf(error_buffer,
 		    "wrong # args: should be \"%.50s deselect\"",
 		    argv[0]);
+	    Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
 	    goto error;
 	}
 	if (butPtr->type == TYPE_CHECK_BUTTON) {
@@ -498,9 +501,10 @@ ButtonWidgetCmd(clientData, interp, argc, argv)
 	int i;
 
 	if (argc > 2) {
-	    sprintf(interp->result,
+	    sprintf(error_buffer,
 		    "wrong # args: should be \"%.50s flash\"",
 		    argv[0]);
+	    Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
 	    goto error;
 	}
 	if (butPtr->state != tkDisabledUid) {
@@ -515,17 +519,18 @@ ButtonWidgetCmd(clientData, interp, argc, argv)
 		 * cleared the REDRAW_PENDING flag.
 		 */
 
-		Tk_CancelIdleCall(DisplayButton, (ClientData) butPtr);
+		Tcl_CancelIdleCall(DisplayButton, (ClientData) butPtr);
 		Ctk_DisplayFlush(Tk_Display(butPtr->tkwin));
-		Tk_Sleep(50);
+		Tcl_Sleep(50);
 	    }
 	}
     } else if ((c == 'i') && (strncmp(argv[1], "invoke", length) == 0)
 	    && (butPtr->type > TYPE_LABEL)) {
 	if (argc > 2) {
-	    sprintf(interp->result,
+	    sprintf(error_buffer,
 		    "wrong # args: should be \"%.50s invoke\"",
 		    argv[0]);
+	    Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
 	    goto error;
 	}
 	if (butPtr->state != tkDisabledUid) {
@@ -534,9 +539,10 @@ ButtonWidgetCmd(clientData, interp, argc, argv)
     } else if ((c == 's') && (strncmp(argv[1], "select", length) == 0)
 	    && (butPtr->type >= TYPE_CHECK_BUTTON)) {
 	if (argc > 2) {
-	    sprintf(interp->result,
+	    sprintf(error_buffer,
 		    "wrong # args: should be \"%.50s select\"",
 		    argv[0]);
+	    Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
 	    goto error;
 	}
 	if (Tcl_SetVar(interp, butPtr->selVarName, butPtr->onValue,
@@ -546,9 +552,10 @@ ButtonWidgetCmd(clientData, interp, argc, argv)
     } else if ((c == 't') && (strncmp(argv[1], "toggle", length) == 0)
 	    && (length >= 2) && (butPtr->type == TYPE_CHECK_BUTTON)) {
 	if (argc > 2) {
-	    sprintf(interp->result,
+	    sprintf(error_buffer,
 		    "wrong # args: should be \"%.50s toggle\"",
 		    argv[0]);
+	    Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
 	    goto error;
 	}
 	if (butPtr->flags & SELECTED) {
@@ -563,9 +570,10 @@ ButtonWidgetCmd(clientData, interp, argc, argv)
 	    }
 	}
     } else {
-	sprintf(interp->result,
+	sprintf(error_buffer,
 		"bad option \"%.50s\":  must be %s", argv[1],
 		optionStrings[butPtr->type]);
+	Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
 	goto error;
     }
     Tk_Release((ClientData) butPtr);
@@ -759,7 +767,7 @@ ConfigureButton(interp, butPtr, argc, argv, flags)
      */
 
     if (Tk_IsMapped(butPtr->tkwin) && !(butPtr->flags & REDRAW_PENDING)) {
-	Tk_DoWhenIdle(DisplayButton, (ClientData) butPtr);
+	Tcl_DoWhenIdle(DisplayButton, (ClientData) butPtr);
 	butPtr->flags |= REDRAW_PENDING;
     }
 
@@ -901,7 +909,7 @@ ButtonEventProc(clientData, eventPtr)
     Button *butPtr = (Button *) clientData;
     if (eventPtr->type == CTK_EXPOSE_EVENT) {
 	if ((butPtr->tkwin != NULL) && !(butPtr->flags & REDRAW_PENDING)) {
-	    Tk_DoWhenIdle(DisplayButton, (ClientData) butPtr);
+	    Tcl_DoWhenIdle(DisplayButton, (ClientData) butPtr);
 	    butPtr->flags |= REDRAW_PENDING;
 	}
     } else if (eventPtr->type == CTK_DESTROY_EVENT) {
@@ -911,7 +919,7 @@ ButtonEventProc(clientData, eventPtr)
 	    	    Tcl_GetCommandName(butPtr->interp, butPtr->widgetCmd));
 	}
 	if (butPtr->flags & REDRAW_PENDING) {
-	    Tk_CancelIdleCall(DisplayButton, (ClientData) butPtr);
+	    Tcl_CancelIdleCall(DisplayButton, (ClientData) butPtr);
 	}
 	Tk_EventuallyFree((ClientData) butPtr, DestroyButton);
     } else if (eventPtr->type == CTK_FOCUS_EVENT) {
@@ -1127,7 +1135,7 @@ ButtonVarProc(clientData, interp, name1, name2, flags)
     redisplay:
     if ((butPtr->tkwin != NULL) && Tk_IsMapped(butPtr->tkwin)
 	    && !(butPtr->flags & REDRAW_PENDING)) {
-	Tk_DoWhenIdle(DisplayButton, (ClientData) butPtr);
+	Tcl_DoWhenIdle(DisplayButton, (ClientData) butPtr);
 	butPtr->flags |= REDRAW_PENDING;
     }
     return (char *) NULL;
@@ -1192,7 +1200,7 @@ ButtonTextVarProc(clientData, interp, name1, name2, flags)
 
     if ((butPtr->tkwin != NULL) && Tk_IsMapped(butPtr->tkwin)
 	    && !(butPtr->flags & REDRAW_PENDING)) {
-	Tk_DoWhenIdle(DisplayButton, (ClientData) butPtr);
+	Tcl_DoWhenIdle(DisplayButton, (ClientData) butPtr);
 	butPtr->flags |= REDRAW_PENDING;
     }
     return (char *) NULL;
