@@ -30,6 +30,7 @@ static void		WaitWindowProc _ANSI_ARGS_((ClientData clientData,
 
 static int		GetFocusOk _ANSI_ARGS_((Tcl_Interp *interp,
 			    TkWindow *winPtr, int *flagPtr));
+static char error_buffer[200];
 
 /*
  *----------------------------------------------------------------------
@@ -151,7 +152,7 @@ Tk_BindCmd(clientData, interp, argc, argv)
 	    Tcl_ResetResult(interp);
 	    return TCL_OK;
 	}
-	interp->result = command;
+	Tcl_SetResult(interp, command, TCL_VOLATILE);
     } else {
 	Tk_GetAllBindings(interp, winPtr->mainPtr->bindingTable, object);
     }
@@ -863,7 +864,7 @@ Tk_WinfoCmd(clientData, interp, argc, argv)
     	result = Ctk_Unsupported(interp, "winfo atomname");
     } else if ((c == 'c') && (strncmp(argv[1], "cells", length) == 0)
 	    && (length >= 2)) {
-	interp->result = "2";
+	Tcl_SetResult(interp,"2", TCL_STATIC);
     } else if ((c == 'c') && (strncmp(argv[1], "children", length) == 0)
 	    && (length >= 2)) {
 	SETUP("children");
@@ -902,10 +903,10 @@ Tk_WinfoCmd(clientData, interp, argc, argv)
     } else if ((c == 'c') && (strncmp(argv[1], "class", length) == 0)
 	    && (length >= 2)) {
 	SETUP("class");
-	interp->result = Tk_Class(window);
+	Tcl_SetResult(interp,Tk_Class(window), TCL_VOLATILE);
     } else if ((c == 'c') && (strncmp(argv[1], "colormapfull", length) == 0)
 	    && (length >= 3)) {
-	interp->result = "0";
+	Tcl_SetResult(interp,"0", TCL_STATIC);
     } else if ((c == 'c') && (strncmp(argv[1], "containing", length) == 0)
 	    && (length >= 2)) {
 	/*
@@ -913,7 +914,7 @@ Tk_WinfoCmd(clientData, interp, argc, argv)
 	 */
     	result = Ctk_Unsupported(interp, "winfo containing");
     } else if ((c == 'd') && (strncmp(argv[1], "depth", length) == 0)) {
-	interp->result = "1";
+	Tcl_SetResult(interp,"1", TCL_STATIC);
     } else if ((c == 'e') && (strncmp(argv[1], "exists", length) == 0)) {
 	if (argc != 3) {
 	    argName = "exists";
@@ -921,9 +922,9 @@ Tk_WinfoCmd(clientData, interp, argc, argv)
 	}
 	winPtr = Tk_NameToWindow(interp, argv[2], tkwin);
 	if ((winPtr == (TkWindow *)NULL) || (winPtr->flags & TK_ALREADY_DEAD)) {
-	    interp->result = "0";
+	    Tcl_SetResult(interp,"0",TCL_STATIC);
 	} else {
-	    interp->result = "1";
+	    Tcl_SetResult(interp,"1",TCL_STATIC);
 	}
     } else if ((c == 'f') && (strncmp(argv[1], "fpixels", length) == 0)
 	    && (length >= 2)) {
@@ -933,12 +934,14 @@ Tk_WinfoCmd(clientData, interp, argc, argv)
     	result = Ctk_Unsupported(interp, "winfo fpixels");
     } else if ((c == 'g') && (strncmp(argv[1], "geometry", length) == 0)) {
 	SETUP("geometry");
-	sprintf(interp->result, "%dx%d+%d+%d",
+	sprintf(error_buffer, "%dx%d+%d+%d",
 		Tk_Width(window), Tk_Height(window),
 		Tk_X(window), Tk_Y(window));
+	Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
     } else if ((c == 'h') && (strncmp(argv[1], "height", length) == 0)) {
 	SETUP("height");
-	sprintf(interp->result, "%d", Tk_Height(window));
+	sprintf(error_buffer, "%d", Tk_Height(window));
+	Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
     } else if ((c == 'i') && (strcmp(argv[1], "id") == 0)) {
     	result = Ctk_Unsupported(interp, "winfo id");
     } else if ((c == 'i') && (strncmp(argv[1], "interps", length) == 0)
@@ -947,21 +950,21 @@ Tk_WinfoCmd(clientData, interp, argc, argv)
     } else if ((c == 'i') && (strncmp(argv[1], "ismapped", length) == 0)
 	    && (length >= 2)) {
 	SETUP("ismapped");
-	interp->result = Tk_IsMapped(window) ? "1" : "0";
+	Tcl_SetResult(interp, Tk_IsMapped(window) ? "1" : "0", TCL_STATIC);
     } else if ((c == 'm') && (strncmp(argv[1], "manager", length) == 0)) {
 	SETUP("manager");
 	winPtr = (TkWindow *) window;
 	if (winPtr->geomMgrPtr != NULL) {
-	    interp->result = winPtr->geomMgrPtr->name;
+	    Tcl_SetResult(interp,winPtr->geomMgrPtr->name, TCL_VOLATILE);
 	}
     } else if ((c == 'n') && (strncmp(argv[1], "name", length) == 0)) {
 	SETUP("name");
-	interp->result = Tk_Name(window);
+	Tcl_SetResult(interp, Tk_Name(window), TCL_VOLATILE);
     } else if ((c == 'p') && (strncmp(argv[1], "parent", length) == 0)) {
 	SETUP("parent");
 	winPtr = Ctk_ParentByName(interp, Tk_PathName(window), window);
 	if (winPtr) {
-	    interp->result = winPtr->pathName;
+	    Tcl_SetResult(interp,winPtr->pathName,TCL_VOLATILE);
 	} else {
 	    return TCL_ERROR;
 	}
@@ -984,7 +987,8 @@ Tk_WinfoCmd(clientData, interp, argc, argv)
 	if (Tk_GetPixels(interp, window, argv[3], &pixels) != TCL_OK) {
 	    return TCL_ERROR;
 	}
-	sprintf(interp->result, "%d", pixels);
+	sprintf(error_buffer, "%d", pixels);
+	Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
     } else if ((c == 'p') && (strcmp(argv[1], "pointerx") == 0)) {
     	result = Ctk_Unsupported(interp, "winfo pointerx");
     } else if ((c == 'p') && (strcmp(argv[1], "pointerxy") == 0)) {
@@ -994,33 +998,38 @@ Tk_WinfoCmd(clientData, interp, argc, argv)
     } else if ((c == 'r') && (strncmp(argv[1], "reqheight", length) == 0)
 	    && (length >= 4)) {
 	SETUP("reqheight");
-	sprintf(interp->result, "%d", Tk_ReqHeight(window));
+	sprintf(error_buffer, "%d", Tk_ReqHeight(window));
+	Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
     } else if ((c == 'r') && (strncmp(argv[1], "reqwidth", length) == 0)
 	    && (length >= 4)) {
 	SETUP("reqwidth");
-	sprintf(interp->result, "%d", Tk_ReqWidth(window));
+	sprintf(error_buffer, "%d", Tk_ReqWidth(window));
+	Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
     } else if ((c == 'r') && (strncmp(argv[1], "rgb", length) == 0)
 	    && (length >= 2)) {
     	result = Ctk_Unsupported(interp, "winfo rgb");
     } else if ((c == 'r') && (strcmp(argv[1], "rootx") == 0)) {
 	SETUP("rootx");
-	sprintf(interp->result, "%d", Ctk_AbsLeft(window));
+	sprintf(error_buffer, "%d", Ctk_AbsLeft(window));
+	Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
     } else if ((c == 'r') && (strcmp(argv[1], "rooty") == 0)) {
 	SETUP("rooty");
-	sprintf(interp->result, "%d", Ctk_AbsTop(window));
+	sprintf(error_buffer, "%d", Ctk_AbsTop(window));
+	Tcl_SetResult(interp, error_buffer, TCL_VOLATILE);
     } else if ((c == 's') && (strcmp(argv[1], "screen") == 0)) {
 	SETUP("screen");
 	Tcl_AppendResult(interp, Tk_Display(window)->name, ".", (char *) NULL);
     } else if ((c == 's') && (strncmp(argv[1], "screencells", length) == 0)
 	    && (length >= 7)) {
-    	interp->result = "2";
+    	Tcl_SetResult(interp,"2",TCL_STATIC);
     } else if ((c == 's') && (strncmp(argv[1], "screendepth", length) == 0)
 	    && (length >= 7)) {
-    	interp->result = "1";
+    	Tcl_SetResult(interp,"1",TCL_STATIC);
     } else if ((c == 's') && (strncmp(argv[1], "screenheight", length) == 0)
 	    && (length >= 7)) {
 	SETUP("screenheight");
-	sprintf(interp->result, "%d", Ctk_DisplayHeight(Tk_Display(window)));
+	sprintf(error_buffer, "%d", Ctk_DisplayHeight(Tk_Display(window)));
+	Tcl_SetResult(interp,error_buffer,TCL_VOLATILE);
     } else if ((c == 's') && (strncmp(argv[1], "screenmmheight", length) == 0)
 	    && (length >= 9)) {
     	result = Ctk_Unsupported(interp, "winfo screenmmheight");
@@ -1029,47 +1038,54 @@ Tk_WinfoCmd(clientData, interp, argc, argv)
     	result = Ctk_Unsupported(interp, "winfo screenmmheight");
     } else if ((c == 's') && (strncmp(argv[1], "screenvisual", length) == 0)
 	    && (length >= 7)) {
-	interp->result = "staticgray";
+	Tcl_SetResult(interp,"staticgray",TCL_STATIC);
     } else if ((c == 's') && (strncmp(argv[1], "screenwidth", length) == 0)
 	    && (length >= 7)) {
 	SETUP("screenwidth");
-	sprintf(interp->result, "%d", Ctk_DisplayWidth(Tk_Display(window)));
+	sprintf(error_buffer, "%d", Ctk_DisplayWidth(Tk_Display(window)));
+	Tcl_SetResult(interp,error_buffer,TCL_VOLATILE);
     } else if ((c == 's') && (strncmp(argv[1], "server", length) == 0)
 	    && (length >= 2)) {
     	result = Ctk_Unsupported(interp, "winfo server");
     } else if ((c == 't') && (strncmp(argv[1], "toplevel", length) == 0)) {
 	SETUP("toplevel");
-	interp->result = Tk_PathName(Ctk_TopLevel(window));
+	Tcl_SetResult(interp,Tk_PathName(Ctk_TopLevel(window)), TCL_STATIC);
     } else if ((c == 'v') && (strncmp(argv[1], "viewable", length) == 0)
 	    && (length >= 3)) {
 	SETUP("viewable");
-	interp->result = (window->flags & CTK_DISPLAYED) ? "1" : "0";
+	Tcl_SetResult(interp,(window->flags & CTK_DISPLAYED) ? "1" : "0",
+                      TCL_STATIC);
     } else if ((c == 'v') && (strncmp(argv[1], "visual", length) == 0)) {
-	interp->result = "staticgray";
+	Tcl_SetResult(interp,"staticgray",TCL_STATIC);
     } else if ((c == 'v') && (strncmp(argv[1], "visualsavailable", length) == 0)
 	    && (length >= 7)) {
-	interp->result = "staticgray 1";
+	Tcl_SetResult(interp,"staticgray 1",TCL_STATIC);
     } else if ((c == 'v') && (strncmp(argv[1], "vrootheight", length) == 0)
 	    && (length >= 6)) {
 	SETUP("vrootheight");
-	sprintf(interp->result, "%d", Ctk_DisplayHeight(Tk_Display(window)));
+	sprintf(error_buffer, "%d", Ctk_DisplayHeight(Tk_Display(window)));
+	Tcl_SetResult(interp,error_buffer,TCL_VOLATILE);
     } else if ((c == 'v') && (strncmp(argv[1], "vrootwidth", length) == 0)
 	    && (length >= 6)) {
 	SETUP("vrootwidth");
-	sprintf(interp->result, "%d", Ctk_DisplayWidth(Tk_Display(window)));
+	sprintf(error_buffer, "%d", Ctk_DisplayWidth(Tk_Display(window)));
+	Tcl_SetResult(interp,error_buffer,TCL_VOLATILE);
     } else if ((c == 'v') && (strcmp(argv[1], "vrootx") == 0)) {
-    	interp->result = "0";
+	Tcl_SetResult(interp,"0",TCL_STATIC);
     } else if ((c == 'v') && (strcmp(argv[1], "vrooty") == 0)) {
-    	interp->result = "0";
+	Tcl_SetResult(interp,"0",TCL_STATIC);
     } else if ((c == 'w') && (strncmp(argv[1], "width", length) == 0)) {
 	SETUP("width");
-	sprintf(interp->result, "%d", Tk_Width(window));
+	sprintf(error_buffer, "%d", Tk_Width(window));
+	Tcl_SetResult(interp,error_buffer,TCL_VOLATILE);
     } else if ((c == 'x') && (argv[1][1] == '\0')) {
 	SETUP("x");
-	sprintf(interp->result, "%d", Tk_X(window));
+	sprintf(error_buffer, "%d", Tk_X(window));
+	Tcl_SetResult(interp,error_buffer,TCL_VOLATILE);
     } else if ((c == 'y') && (argv[1][1] == '\0')) {
 	SETUP("y");
-	sprintf(interp->result, "%d", Tk_Y(window));
+	sprintf(error_buffer, "%d", Tk_Y(window));
+	Tcl_SetResult(interp,error_buffer,TCL_VOLATILE);
     } else {
 	Tcl_AppendResult(interp, "bad option \"", argv[1],
 		"\": must be atom, atomname, cells, children, ",
