@@ -304,7 +304,7 @@ TkInitFrame(interp, tkwin, toplevel, argc, argv)
     } else {
 	tkwin->fillStyle = CTK_INVISIBLE_STYLE;
     }
-    interp->result = Tk_PathName(framePtr->tkwin);
+    Tcl_SetResult(interp,Tk_PathName(framePtr->tkwin),TCL_VOLATILE);
     return (char *) framePtr;
 }
 
@@ -476,7 +476,7 @@ ConfigureFrame(interp, framePtr, argc, argv, flags)
 
     if (Tk_IsMapped(framePtr->tkwin)) {
 	if (!(framePtr->flags & REDRAW_PENDING)) {
-	    Tk_DoWhenIdle(DisplayFrame, (ClientData) framePtr);
+	    Tcl_DoWhenIdle(DisplayFrame, (ClientData) framePtr);
 	}
 	framePtr->flags |= REDRAW_PENDING|CLEAR_NEEDED;
     }
@@ -542,7 +542,7 @@ FrameEventProc(clientData, eventPtr)
 
     if (eventPtr->type == CTK_EXPOSE_EVENT) {
 	if ((framePtr->tkwin != NULL) && !(framePtr->flags & REDRAW_PENDING)) {
-	    Tk_DoWhenIdle(DisplayFrame, (ClientData) framePtr);
+	    Tcl_DoWhenIdle(DisplayFrame, (ClientData) framePtr);
 	    framePtr->flags |= REDRAW_PENDING;
 	}
     } else if (eventPtr->type == CTK_DESTROY_EVENT) {
@@ -552,7 +552,7 @@ FrameEventProc(clientData, eventPtr)
 		    Tcl_GetCommandName(framePtr->interp, framePtr->widgetCmd));
 	}
 	if (framePtr->flags & REDRAW_PENDING) {
-	    Tk_CancelIdleCall(DisplayFrame, (ClientData) framePtr);
+	    Tcl_CancelIdleCall(DisplayFrame, (ClientData) framePtr);
 	}
 	Tk_EventuallyFree((ClientData) framePtr, DestroyFrame);
     }
