@@ -52,6 +52,8 @@ static Tk_Window mainWindow;	/* The main window for the application.  If
 static Tcl_Interp *interp;	/* Interpreter for this application. */
 static Tcl_DString command;	/* Used to assemble lines of terminal input
 				 * into Tcl commands. */
+static Tcl_DString line;	/* Used to read the next line from the
+				 * terminal input. */
 static int tty;			/* Non-zero means standard input is a
 				 * terminal-like device.  Zero means it's
 				 * a file. */
@@ -120,6 +122,7 @@ Tk_Main(argc, argv, appInitProc)
     char buf[20];
     int code;
     size_t length;
+    Tcl_Channel inChannel, outChannel, errChannel, chan;
 
     interp = Tcl_CreateInterp();
 #ifdef TCL_MEM_DEBUG
@@ -243,8 +246,14 @@ Tk_Main(argc, argv, appInitProc)
      */
 
     if ((*appInitProc)(interp) != TCL_OK) {
-	fprintf(stderr, "application specific initialization failed: %s\n",
-		interp->result);
+       errChannel = Tcl_GetStdChannel(TCL_STDERR);
+       if (errChannel) {
+            Tcl_Write(errChannel,
+                   "application-specific initialization failed: ", -1);
+            Tcl_Write(errChannel, interp->result, -1);
+            Tcl_Write(errChannel, "\n", 1);
+        }
+
 	goto error;
     }
 
@@ -253,7 +262,7 @@ Tk_Main(argc, argv, appInitProc)
      */
 
     if (fileName != NULL) {
-	code = Tcl_VarEval(interp, "source ", fileName, (char *) NULL);
+	code = Tcl_EvalFile(interp, fileName);
 	if (code != TCL_OK) {
 	    goto error;
 	}
@@ -266,24 +275,37 @@ Tk_Main(argc, argv, appInitProc)
 	 * input, and print a prompt if the input device is a terminal.
 	 */
 
-	if (tcl_RcFileName != NULL) {
+	fileName = Tcl_GetVar(interp, "tcl_rcFileName", TCL_GLOBAL_ONLY);
+	if (fileName != NULL) {
 	    Tcl_DString buffer;
 	    char *fullName;
-	    FILE *f;
-    
-	    fullName = Tcl_TildeSubst(interp, tcl_RcFileName, &buffer);
+
+            fullName = Tcl_TranslateFileName(interp, fileName, &buffer);
 	    if (fullName == NULL) {
-		fprintf(stderr, "%s\n", interp->result);
+               errChannel = Tcl_GetStdChannel(TCL_STDERR);
+               if (errChannel) {
+                    Tcl_Write(errChannel, interp->result, -1);
+                    Tcl_Write(errChannel, "\n", 1);
+                }
 	    } else {
-		f = fopen(fullName, "r");
-		if (f != NULL) {
-		    code = Tcl_EvalFile(interp, fullName);
-		    if (code != TCL_OK) {
-			fprintf(stderr, "%s\n", interp->result);
-		    }
-		    fclose(f);
-		}
+
+                /*
+                 * NOTE: The following relies on O_RDONLY==0.
+                 */
+                
+                chan = Tcl_OpenFileChannel(interp, fullName, "r", 0);
+                if (chan != (Tcl_Channel) NULL) {
+                    Tcl_Close(NULL, chan);
+                    if (Tcl_EvalFile(interp, fullName) != TCL_OK) {
+                       errChannel = Tcl_GetStdChannel(TCL_STDERR);
+                       if (errChannel) {
+                            Tcl_Write(errChannel, interp->result, -1);
+                            Tcl_Write(errChannel, "\n", 1);
+                        }
+                    }
+                }
 	    }
+
 	    Tcl_DStringFree(&buffer);
 	}
 	if (tty &&
@@ -297,14 +319,23 @@ Tk_Main(argc, argv, appInitProc)
 		goto error;
 	    }
 	} else {
-	    Tk_CreateFileHandler(0, TK_READABLE, StdinProc, (ClientData) 0);
+	    Tcl_CreateFileHandler(0, TCL_READABLE, StdinProc, (ClientData) 0);
+	    inChannel = Tcl_GetStdChannel(TCL_STDIN);
+	    if (inChannel) {
+		Tcl_CreateChannelHandler(inChannel, TCL_READABLE, StdinProc,
+					(ClientData) inChannel);
+	    }
 	    if (tty) {
 		Prompt(interp, 0);
 	    }
 	}
     }
-    fflush(stdout);
+    outChannel = Tcl_GetStdChannel(TCL_STDOUT);
+    if (outChannel) {
+       Tcl_Flush(outChannel);
+    }
     Tcl_DStringInit(&command);
+    Tcl_DStringInit(&line);
     Tcl_ResetResult(interp);
 
     /*
@@ -324,12 +355,20 @@ Tk_Main(argc, argv, appInitProc)
     exit(1);
 
 error:
-    msg = Tcl_GetVar(interp, "errorInfo", TCL_GLOBAL_ONLY);
-    if (msg == NULL) {
-	msg = interp->result;
+    /*
+     * The following statement guarantees that the errorInfo
+     * variable is set properly.
+     */
+
+    Tcl_AddErrorInfo(interp, "");
+    errChannel = Tcl_GetStdChannel(TCL_STDERR);
+    if (errChannel) {
+        Tcl_Write(errChannel, Tcl_GetVar(interp, "errorInfo", TCL_GLOBAL_ONLY),
+               -1);
+        Tcl_Write(errChannel, "\n", 1);
     }
-    fprintf(stderr, "%s\n", msg);
-    Tcl_Eval(interp, errorExitCmd);
+    Tcl_DeleteInterp(interp);
+    Tcl_Exit(1);
 }
 
 /*
@@ -358,56 +397,55 @@ StdinProc(clientData, mask)
     ClientData clientData;		/* Not used. */
     int mask;				/* Not used. */
 {
-#define BUFFER_SIZE 4000
-    char input[BUFFER_SIZE+1];
     static int gotPartial = 0;
     char *cmd;
     int code, count;
+    Tcl_Channel chan = (Tcl_Channel) clientData;
 
-    count = read(fileno(stdin), input, BUFFER_SIZE);
-    if (count <= 0) {
+    count = Tcl_Gets(chan, &line);
+
+    if (count < 0) {
 	if (!gotPartial) {
 	    if (tty) {
-		Tcl_Eval(interp, "exit");
-		exit(1);
+		Tcl_Exit(0);
 	    } else {
-		Tk_DeleteFileHandler(0);
+		Tcl_DeleteChannelHandler(chan, StdinProc, (ClientData) chan);
 	    }
 	    return;
 	} else {
 	    count = 0;
 	}
     }
-    cmd = Tcl_DStringAppend(&command, input, count);
-    if (count != 0) {
-	if ((input[count-1] != '\n') && (input[count-1] != ';')) {
-	    gotPartial = 1;
-	    goto prompt;
-	}
-	if (!Tcl_CommandComplete(cmd)) {
-	    gotPartial = 1;
-	    goto prompt;
-	}
+
+    (void) Tcl_DStringAppend(&command, Tcl_DStringValue(&line), -1);
+    cmd = Tcl_DStringAppend(&command, "\n", -1);
+    Tcl_DStringFree(&line);
+    
+    if (!Tcl_CommandComplete(cmd)) {
+        gotPartial = 1;
+        goto prompt;
     }
     gotPartial = 0;
 
     /*
-     * Disable the stdin file handler while evaluating the command;
+     * Disable the stdin channel handler while evaluating the command;
      * otherwise if the command re-enters the event loop we might
      * process commands from stdin before the current command is
      * finished.  Among other things, this will trash the text of the
      * command being evaluated.
      */
 
-    Tk_CreateFileHandler(0, 0, StdinProc, (ClientData) 0);
+    Tcl_CreateFileHandler(chan, 0, StdinProc, (ClientData) chan);
     code = Tcl_RecordAndEval(interp, cmd, TCL_EVAL_GLOBAL);
-    Tk_CreateFileHandler(0, TK_READABLE, StdinProc, (ClientData) 0);
+    Tcl_CreateChannelHandler(chan, TCL_READABLE, StdinProc, (ClientData) chan);
     Tcl_DStringFree(&command);
     if (*interp->result != 0) {
 	if ((code != TCL_OK) || (tty)) {
 	    /*
 	     * The statement below used to call "printf", but that resulted
 	     * in core dumps under Solaris 2.3 if the result was very long.
+	     *
+	     * NOTE: This probably will not work under Windows either.
 	     */
 
 	    puts(interp->result);
