@@ -68,7 +68,7 @@ typedef struct Packer {
 /*
  * Flag values for Packer structures:
  *
- * REQUESTED_REPACK:		1 means a Tk_DoWhenIdle request
+ * REQUESTED_REPACK:		1 means a Tcl_DoWhenIdle request
  *				has already been made to repack
  *				all the slaves of this window.
  * FILLX:			1 means if frame allocated for window
@@ -341,9 +341,9 @@ Tk_PackCmd(clientData, interp, argc, argv)
 	masterPtr = GetPacker(master);
 	if (argc == 3) {
 	    if (masterPtr->flags & DONT_PROPAGATE) {
-		interp->result = "0";
+		Tcl_SetResult(interp,"0",TCL_STATIC);
 	    } else {
-		interp->result = "1";
+		Tcl_SetResult(interp,"1",TCL_STATIC);
 	    }
 	    return TCL_OK;
 	}
@@ -363,7 +363,7 @@ Tk_PackCmd(clientData, interp, argc, argv)
 	    }
 	    if (!(masterPtr->flags & REQUESTED_REPACK)) {
 		masterPtr->flags |= REQUESTED_REPACK;
-		Tk_DoWhenIdle(ArrangePacking, (ClientData) masterPtr);
+		Tcl_DoWhenIdle(ArrangePacking, (ClientData) masterPtr);
 	    }
 	} else {
 	    masterPtr->flags |= DONT_PROPAGATE;
@@ -451,7 +451,7 @@ PackReqProc(clientData, tkwin)
     packPtr = packPtr->masterPtr;
     if (!(packPtr->flags & REQUESTED_REPACK)) {
 	packPtr->flags |= REQUESTED_REPACK;
-	Tk_DoWhenIdle(ArrangePacking, (ClientData) packPtr);
+	Tcl_DoWhenIdle(ArrangePacking, (ClientData) packPtr);
     }
 }
 
@@ -493,7 +493,7 @@ PackLostSlaveProc(clientData, tkwin)
  *
  * ArrangePacking --
  *
- *	This procedure is invoked (using the Tk_DoWhenIdle
+ *	This procedure is invoked (using the Tcl_DoWhenIdle
  *	mechanism) to re-layout a set of windows managed by
  *	the packer.  It is invoked at idle time so that a
  *	series of packer requests can be merged into a single
@@ -618,7 +618,7 @@ ArrangePacking(clientData)
 	    && !(masterPtr->flags & DONT_PROPAGATE)) {
 	Tk_GeometryRequest(masterPtr->tkwin, maxWidth, maxHeight);
 	masterPtr->flags |= REQUESTED_REPACK;
-	Tk_DoWhenIdle(ArrangePacking, (ClientData) masterPtr);
+	Tcl_DoWhenIdle(ArrangePacking, (ClientData) masterPtr);
 	goto done;
     }
 
@@ -1213,7 +1213,7 @@ PackAfter(interp, prevPtr, masterPtr, argc, argv)
     }
     if (!(masterPtr->flags & REQUESTED_REPACK)) {
 	masterPtr->flags |= REQUESTED_REPACK;
-	Tk_DoWhenIdle(ArrangePacking, (ClientData) masterPtr);
+	Tcl_DoWhenIdle(ArrangePacking, (ClientData) masterPtr);
     }
     return TCL_OK;
 
@@ -1263,7 +1263,7 @@ Unlink(packPtr)
     }
     if (!(masterPtr->flags & REQUESTED_REPACK)) {
 	masterPtr->flags |= REQUESTED_REPACK;
-	Tk_DoWhenIdle(ArrangePacking, (ClientData) masterPtr);
+	Tcl_DoWhenIdle(ArrangePacking, (ClientData) masterPtr);
     }
     if (masterPtr->abortPtr != NULL) {
 	*masterPtr->abortPtr = 1;
@@ -1329,14 +1329,14 @@ PackStructureProc(clientData, eventPtr)
 	if ((packPtr->slavePtr != NULL)
 		&& !(packPtr->flags & REQUESTED_REPACK)) {
 	    packPtr->flags |= REQUESTED_REPACK;
-	    Tk_DoWhenIdle(ArrangePacking, (ClientData) packPtr);
+	    Tcl_DoWhenIdle(ArrangePacking, (ClientData) packPtr);
 	}
 	if (packPtr->doubleBw != 2*Tk_BorderWidth(packPtr->tkwin)) {
 	    if ((packPtr->masterPtr != NULL)
 		    && !(packPtr->masterPtr->flags & REQUESTED_REPACK)) {
 		packPtr->doubleBw = 2*Tk_BorderWidth(packPtr->tkwin);
 		packPtr->masterPtr->flags |= REQUESTED_REPACK;
-		Tk_DoWhenIdle(ArrangePacking, (ClientData) packPtr->masterPtr);
+		Tcl_DoWhenIdle(ArrangePacking, (ClientData) packPtr->masterPtr);
 	    }
 	}
     } else if (eventPtr->type == DestroyNotify) {
@@ -1357,7 +1357,7 @@ PackStructureProc(clientData, eventPtr)
 	Tcl_DeleteHashEntry(Tcl_FindHashEntry(&packerHashTable,
 		(char *) packPtr->tkwin));
 	if (packPtr->flags & REQUESTED_REPACK) {
-	    Tk_CancelIdleCall(ArrangePacking, (ClientData) packPtr);
+	    Tcl_CancelIdleCall(ArrangePacking, (ClientData) packPtr);
 	}
 	packPtr->tkwin = NULL;
 	Tk_EventuallyFree((ClientData) packPtr, DestroyPacker);
@@ -1370,7 +1370,7 @@ PackStructureProc(clientData, eventPtr)
 	if ((packPtr->slavePtr != NULL)
 		&& !(packPtr->flags & REQUESTED_REPACK)) {
 	    packPtr->flags |= REQUESTED_REPACK;
-	    Tk_DoWhenIdle(ArrangePacking, (ClientData) packPtr);
+	    Tcl_DoWhenIdle(ArrangePacking, (ClientData) packPtr);
 	}
     } else if (eventPtr->type == UnmapNotify) {
 	Packer *packPtr2;
@@ -1722,7 +1722,7 @@ ConfigureSlaves(interp, tkwin, argc, argv)
 	}
 	if (!(masterPtr->flags & REQUESTED_REPACK)) {
 	    masterPtr->flags |= REQUESTED_REPACK;
-	    Tk_DoWhenIdle(ArrangePacking, (ClientData) masterPtr);
+	    Tcl_DoWhenIdle(ArrangePacking, (ClientData) masterPtr);
 	}
     }
     return TCL_OK;
