@@ -217,7 +217,7 @@ Tk_TextCmd(clientData, interp, argc, argv)
 	Tk_DestroyWindow(textPtr->tkwin);
 	return TCL_ERROR;
     }
-    interp->result = Tk_PathName(textPtr->tkwin);
+    Tcl_SetResult(interp,Tk_PathName(textPtr->tkwin),TCL_VOLATILE);
 
     return TCL_OK;
 }
@@ -275,7 +275,9 @@ TextWidgetCmd(clientData, interp, argc, argv)
 	    goto done;
 	}
 	if (TkTextCharBbox(textPtr, &index1, &x, &y, &width, &height) == 0) {
-	    sprintf(interp->result, "%d %d %d %d", x, y, width, height);
+	    char buffer[80];
+	    sprintf(buffer, "%d %d %d %d", x, y, width, height);
+	    Tcl_SetResult(interp,buffer,TCL_VOLATILE);
 	}
     } else if ((c == 'c') && (strncmp(argv[1], "cget", length) == 0)
 	    && (length >= 2)) {
@@ -333,7 +335,7 @@ TextWidgetCmd(clientData, interp, argc, argv)
 	} else {
 	    goto compareError;
 	}
-	interp->result = (value) ? "1" : "0";
+	Tcl_SetResult(interp,(value) ? "1" : "0",TCL_STATIC);
     } else if ((c == 'c') && (strncmp(argv[1], "configure", length) == 0)
 	    && (length >= 3)) {
 	if (argc == 2) {
@@ -355,7 +357,7 @@ TextWidgetCmd(clientData, interp, argc, argv)
 	    goto done;
 	}
 	if (argc == 2) {
-	    interp->result = (tkBTreeDebug) ? "1" : "0";
+	    Tcl_SetResult(interp,(tkBTreeDebug) ? "1" : "0",TCL_STATIC);
 	} else {
 	    if (Tcl_GetBoolean(interp, argv[2], &tkBTreeDebug) != TCL_OK) {
 		result = TCL_ERROR;
@@ -391,8 +393,10 @@ TextWidgetCmd(clientData, interp, argc, argv)
 	}
 	if (TkTextDLineInfo(textPtr, &index1, &x, &y, &width, &height, &base)
 		== 0) {
-	    sprintf(interp->result, "%d %d %d %d %d",
+	    char buffer[100];
+	    sprintf(buffer, "%d %d %d %d %d",
 	    	    x, y, width, height, base);
+	    Tcl_SetResult(interp,buffer,TCL_VOLATILE);
 	}
     } else if ((c == 'g') && (strncmp(argv[1], "get", length) == 0)) {
 	if ((argc != 3) && (argc != 4)) {
@@ -1077,7 +1081,7 @@ TextSearchCmd(textPtr, interp, argc, argv)
 	    backwards = 1;
 	} else if ((c == 'c') && (strncmp(argv[i], "-count", length) == 0)) {
 	    if (i >= (argc-1)) {
-		interp->result = "no value given for \"-count\" option";
+		Tcl_SetResult(interp,"no value given for \"-count\" option",TCL_STATIC);
 		return TCL_ERROR;
 	    }
 	    i++;
