@@ -431,6 +431,33 @@ Tk_HandleEvent(eventPtr)
     }
     pendingPtr = ip.nextPtr;
 }
+
+ /*
+  *--------------------------------------------------------------
+  *
+  * Tk_DoOneEvent --
+  *
+  *     Flushes displays and the calls Tcl_DoOneEvent.
+  *
+  * Results:
+  *     See Tcl_DoOneEvent().
+  *
+  * Side effects:
+  *     Displays get flushed.
+  *
+  *--------------------------------------------------------------
+  */
+
+int Tk_DoOneEvent(int flags)
+{
+       int retval;
+       Ctk_DisplayFlush(NULL);
+       retval = Tcl_DoOneEvent(flags);
+       Ctk_DisplayFlush(NULL);
+
+       return(retval);
+}
+
 
 /*
  *--------------------------------------------------------------
